==> forestry_1.10.2-5.2.17.377-sources.jar: forestry/core/utils/VillagerTradeLists.java <==
package forestry.core.utils;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Random;

import net.minecraft.block.Block;
import net.minecraft.entity.passive.EntityVillager;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.ItemStack;
import net.minecraft.village.MerchantRecipe;
import net.minecraft.village.MerchantRecipeList;

public class VillagerTradeLists {
	/**
	 * Copy of {@link net.minecraft.entity.passive.EntityVillager.ItemAndEmeraldToItem}
	 * that takes ItemStacks as parameters and has emerald price info
	 */
	public static class GiveItemForItemAndEmerald implements EntityVillager.ITradeList {
		@Nonnull
		public ItemStack buyingItemStack;
		@Nullable
		public EntityVillager.PriceInfo buyingPriceInfo;
		@Nullable
		public EntityVillager.PriceInfo emeraldPriceInfo;
		@Nonnull
		public ItemStack sellingItemstack;
		@Nullable
		public EntityVillager.PriceInfo sellingPriceInfo;

		public GiveItemForItemAndEmerald(
				@Nonnull ItemStack buyingItemStack,
				@Nullable EntityVillager.PriceInfo buyingPriceInfo,
				@Nullable EntityVillager.PriceInfo emeraldPriceInfo,
				@Nonnull ItemStack sellingItemstack,
				@Nullable EntityVillager.PriceInfo sellingPriceInfo) {
			this.buyingItemStack = buyingItemStack;
			this.buyingPriceInfo = buyingPriceInfo;
			this.emeraldPriceInfo = emeraldPriceInfo;
			this.sellingItemstack = sellingItemstack;
			this.sellingPriceInfo = sellingPriceInfo;
		}

		@Override
		public void func_179401_a(MerchantRecipeList recipeList, Random random) {
			int buyAmount = 1;
			if (this.buyingPriceInfo != null) {
				buyAmount = this.buyingPriceInfo.func_179412_a(random);
			}

			int emeraldAmount = 1;
			if (this.emeraldPriceInfo != null) {
				emeraldAmount = this.emeraldPriceInfo.func_179412_a(random);
			}

			int sellAmount = 1;
			if (this.sellingPriceInfo != null) {
				sellAmount = this.sellingPriceInfo.func_179412_a(random);
			}

			ItemStack buyItemStack = this.buyingItemStack.func_77946_l();
			buyItemStack.field_77994_a = buyAmount;
			ItemStack sellItemStack = this.sellingItemstack.func_77946_l();
			sellItemStack.field_77994_a = sellAmount;
			recipeList.add(new MerchantRecipe(buyItemStack, new ItemStack(Items.field_151166_bC, emeraldAmount, 0), sellItemStack));
		}
	}

	/**
	 * Copy of {@link EntityVillager.EmeraldForItems}
	 * that takes itemStack as a parameter
	 */
	public static class GiveEmeraldForItems implements EntityVillager.ITradeList {
		public ItemStack buyingItem;
		public EntityVillager.PriceInfo price;

		public GiveEmeraldForItems(ItemStack itemIn, EntityVillager.PriceInfo priceIn) {
			this.buyingItem = itemIn;
			this.price = priceIn;
		}

		/**
		 * Affects the given MerchantRecipeList to possibly add or remove MerchantRecipes.
		 */
		@Override
		public void func_179401_a(MerchantRecipeList recipeList, Random random) {
			int buyAmount = 1;
			if (this.price != null) {
				buyAmount = this.price.func_179412_a(random);
			}

			ItemStack itemToBuy = this.buyingItem.func_77946_l();
			itemToBuy.field_77994_a = buyAmount;
			recipeList.add(new MerchantRecipe(itemToBuy, Items.field_151166_bC));
		}
	}

	/**
	 * Copy of {@link EntityVillager.ListItemForEmeralds}
	 * that copies itemStacks properly
	 */
	public static class GiveItemForEmeralds implements EntityVillager.ITradeList {
		@Nullable
		public EntityVillager.PriceInfo emeraldPriceInfo;
		@Nonnull
		public ItemStack itemToSell;
		@Nullable
		public EntityVillager.PriceInfo sellInfo;

		public GiveItemForEmeralds(@Nullable EntityVillager.PriceInfo emeraldPriceInfo, @Nonnull ItemStack itemToSell, @Nullable EntityVillager.PriceInfo sellInfo) {
			this.emeraldPriceInfo = emeraldPriceInfo;
			this.itemToSell = itemToSell;
			this.sellInfo = sellInfo;
		}

		@Override
		public void func_179401_a(MerchantRecipeList recipeList, Random random) {
			int i = 1;
			if (this.sellInfo != null) {
				i = this.sellInfo.func_179412_a(random);
			}

			int j = 1;
			if (this.emeraldPriceInfo != null) {
				j = this.emeraldPriceInfo.func_179412_a(random);
			}

			ItemStack sellStack = this.itemToSell.func_77946_l();
			sellStack.field_77994_a = i;

			ItemStack emeralds = new ItemStack(Items.field_151166_bC, j);

			recipeList.add(new MerchantRecipe(emeralds, sellStack));
		}
	}

	public static class GiveItemForLogsAndEmeralds implements EntityVillager.ITradeList {
		@Nonnull
		public ItemStack itemToSell;
		@Nonnull
		public EntityVillager.PriceInfo itemInfo;
		@Nonnull
		public EntityVillager.PriceInfo logsInfo;
		@Nonnull
		public EntityVillager.PriceInfo emeraldsInfo;

		public GiveItemForLogsAndEmeralds(@Nonnull ItemStack itemToSell, @Nonnull EntityVillager.PriceInfo itemInfo, @Nonnull EntityVillager.PriceInfo logsInfo, @Nonnull EntityVillager.PriceInfo emeraldsInfo) {
			this.itemToSell = itemToSell;
			this.itemInfo = itemInfo;
			this.logsInfo = logsInfo;
			this.emeraldsInfo = emeraldsInfo;
		}

		@Override
		public void func_179401_a(MerchantRecipeList recipeList, Random random) {
			int itemAmount = this.itemInfo.func_179412_a(random);
			int emeraldsAmount = this.emeraldsInfo.func_179412_a(random);
			int logsAmount = this.logsInfo.func_179412_a(random);

			ItemStack itemToSell = this.itemToSell.func_77946_l();
			itemToSell.field_77994_a = itemAmount;

			int logMeta = random.nextInt(6);
			Block log;
			if (logMeta < 4) {
				log = Blocks.field_150364_r;
			} else {
				log = Blocks.field_150363_s;
				logMeta -= 4;
			}
			ItemStack randomLog = new ItemStack(log, logsAmount, logMeta);

			recipeList.add(new MerchantRecipe(randomLog, new ItemStack(Items.field_151166_bC, emeraldsAmount), itemToSell));
		}
	}
	public static class GiveItemForTwoItems implements EntityVillager.ITradeList {
		@Nonnull
		public ItemStack buyingItemStack;
		@Nullable
		public EntityVillager.PriceInfo buyingPriceInfo;
		@Nonnull
		public ItemStack buyingItemStackTwo;
		@Nullable
		public EntityVillager.PriceInfo buyingPriceItemTwoInfo;
		@Nonnull
		public ItemStack sellingItemstack;
		@Nullable
		public EntityVillager.PriceInfo sellingPriceInfo;

		public GiveItemForTwoItems(
				@Nonnull ItemStack buyingItemStack,
				@Nullable EntityVillager.PriceInfo buyingPriceInfo,
				@Nonnull ItemStack buyingItemStackTwo,
				@Nullable EntityVillager.PriceInfo buyingPriceItemTwoInfo,
				@Nonnull ItemStack sellingItemstack,
				@Nullable EntityVillager.PriceInfo sellingPriceInfo) {
			this.buyingItemStack = buyingItemStack;
			this.buyingPriceInfo = buyingPriceInfo;
			this.buyingItemStackTwo = buyingItemStackTwo;
			this.buyingPriceItemTwoInfo = buyingPriceItemTwoInfo;
			this.sellingItemstack = sellingItemstack;
			this.sellingPriceInfo = sellingPriceInfo;
		}

		@Override
		public void func_179401_a(MerchantRecipeList recipeList, Random random) {
			int buyAmount = 1;
			if (this.buyingPriceInfo != null) {
				buyAmount = this.buyingPriceInfo.func_179412_a(random);
			}

			int buyTwoAmount = 1;
			if (this.buyingPriceItemTwoInfo != null) {
				buyTwoAmount = this.buyingPriceItemTwoInfo.func_179412_a(random);
			}

			int sellAmount = 1;
			if (this.sellingPriceInfo != null) {
				sellAmount = this.sellingPriceInfo.func_179412_a(random);
			}

			ItemStack buyItemStack = this.buyingItemStack.func_77946_l();
			buyItemStack.field_77994_a = buyAmount;
			ItemStack buyItemStackTwo = this.buyingItemStackTwo.func_77946_l();
			buyItemStackTwo.field_77994_a = buyTwoAmount;
			ItemStack sellItemStack = this.sellingItemstack.func_77946_l();
			sellItemStack.field_77994_a = sellAmount;
			recipeList.add(new MerchantRecipe(buyItemStack, buyItemStackTwo, sellItemStack));
		}
	}
}

==> forestry_1.12.2-5.8.0.245-sources.jar: forestry/core/utils/VillagerTradeLists.java <==
package forestry.core.utils;

import javax.annotation.Nullable;
import java.util.Random;

import net.minecraft.block.Block;
import net.minecraft.entity.IMerchant;
import net.minecraft.entity.passive.EntityVillager;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.ItemStack;
import net.minecraft.village.MerchantRecipe;
import net.minecraft.village.MerchantRecipeList;

public class VillagerTradeLists {
	/**
	 * Copy of {@link net.minecraft.entity.passive.EntityVillager.ItemAndEmeraldToItem}
	 * that takes ItemStacks as parameters and has emerald price info
	 */
	public static class GiveItemForItemAndEmerald implements EntityVillager.ITradeList {
		public final ItemStack buyingItemStack;
		public final ItemStack sellingItemstack;

		@Nullable
		public final EntityVillager.PriceInfo buyingPriceInfo;
		@Nullable
		public final EntityVillager.PriceInfo emeraldPriceInfo;
		@Nullable
		public final EntityVillager.PriceInfo sellingPriceInfo;

		public GiveItemForItemAndEmerald(
				ItemStack buyingItemStack,
				@Nullable EntityVillager.PriceInfo buyingPriceInfo,
				@Nullable EntityVillager.PriceInfo emeraldPriceInfo,
				ItemStack sellingItemstack,
				@Nullable EntityVillager.PriceInfo sellingPriceInfo) {
			this.buyingItemStack = buyingItemStack;
			this.buyingPriceInfo = buyingPriceInfo;
			this.emeraldPriceInfo = emeraldPriceInfo;
			this.sellingItemstack = sellingItemstack;
			this.sellingPriceInfo = sellingPriceInfo;
		}

		@Override
		public void func_190888_a(IMerchant merchant, MerchantRecipeList recipeList, Random random) {
			int buyAmount = 1;
			if (this.buyingPriceInfo != null) {
				buyAmount = this.buyingPriceInfo.func_179412_a(random);
			}

			int emeraldAmount = 1;
			if (this.emeraldPriceInfo != null) {
				emeraldAmount = this.emeraldPriceInfo.func_179412_a(random);
			}

			int sellAmount = 1;
			if (this.sellingPriceInfo != null) {
				sellAmount = this.sellingPriceInfo.func_179412_a(random);
			}

			ItemStack buyItemStack = this.buyingItemStack.func_77946_l();
			buyItemStack.func_190920_e(buyAmount);
			ItemStack sellItemStack = this.sellingItemstack.func_77946_l();
			sellItemStack.func_190920_e(sellAmount);
			recipeList.add(new MerchantRecipe(buyItemStack, new ItemStack(Items.field_151166_bC, emeraldAmount, 0), sellItemStack));
		}
	}

	/**
	 * Copy of {@link EntityVillager.EmeraldForItems}
	 * that takes itemStack as a parameter
	 */
	public static class GiveEmeraldForItems implements EntityVillager.ITradeList {
		public final ItemStack buyingItem;
		@Nullable
		public final EntityVillager.PriceInfo price;

		public GiveEmeraldForItems(ItemStack itemIn, @Nullable EntityVillager.PriceInfo priceIn) {
			this.buyingItem = itemIn;
			this.price = priceIn;
		}

		/**
		 * Affects the given MerchantRecipeList to possibly add or remove MerchantRecipes.
		 */
		@Override
		public void func_190888_a(IMerchant merchant, MerchantRecipeList recipeList, Random random) {
			int buyAmount = 1;
			if (this.price != null) {
				buyAmount = this.price.func_179412_a(random);
			}

			ItemStack itemToBuy = this.buyingItem.func_77946_l();
			itemToBuy.func_190920_e(buyAmount);
			recipeList.add(new MerchantRecipe(itemToBuy, Items.field_151166_bC));
		}
	}

	/**
	 * Copy of {@link EntityVillager.ListItemForEmeralds}
	 * that copies itemStacks properly
	 */
	public static class GiveItemForEmeralds implements EntityVillager.ITradeList {
		public final ItemStack itemToSell;
		@Nullable
		public final EntityVillager.PriceInfo emeraldPriceInfo;
		@Nullable
		public final EntityVillager.PriceInfo sellInfo;

		public GiveItemForEmeralds(@Nullable EntityVillager.PriceInfo emeraldPriceInfo, ItemStack itemToSell, @Nullable EntityVillager.PriceInfo sellInfo) {
			this.emeraldPriceInfo = emeraldPriceInfo;
			this.itemToSell = itemToSell;
			this.sellInfo = sellInfo;
		}

		@Override
		public void func_190888_a(IMerchant merchant, MerchantRecipeList recipeList, Random random) {
			int i = 1;
			if (this.sellInfo != null) {
				i = this.sellInfo.func_179412_a(random);
			}

			int j = 1;
			if (this.emeraldPriceInfo != null) {
				j = this.emeraldPriceInfo.func_179412_a(random);
			}

			ItemStack sellStack = this.itemToSell.func_77946_l();
			sellStack.func_190920_e(i);

			ItemStack emeralds = new ItemStack(Items.field_151166_bC, j);

			recipeList.add(new MerchantRecipe(emeralds, sellStack));
		}
	}

	public static class GiveItemForLogsAndEmeralds implements EntityVillager.ITradeList {

		public final ItemStack itemToSell;

		public final EntityVillager.PriceInfo itemInfo;

		public final EntityVillager.PriceInfo logsInfo;

		public final EntityVillager.PriceInfo emeraldsInfo;

		public GiveItemForLogsAndEmeralds(ItemStack itemToSell, EntityVillager.PriceInfo itemInfo, EntityVillager.PriceInfo logsInfo, EntityVillager.PriceInfo emeraldsInfo) {
			this.itemToSell = itemToSell;
			this.itemInfo = itemInfo;
			this.logsInfo = logsInfo;
			this.emeraldsInfo = emeraldsInfo;
		}

		@Override
		public void func_190888_a(IMerchant merchant, MerchantRecipeList recipeList, Random random) {
			int itemAmount = this.itemInfo.func_179412_a(random);
			int emeraldsAmount = this.emeraldsInfo.func_179412_a(random);
			int logsAmount = this.logsInfo.func_179412_a(random);

			ItemStack itemToSell = this.itemToSell.func_77946_l();
			itemToSell.func_190920_e(itemAmount);

			int logMeta = random.nextInt(6);
			Block log;
			if (logMeta < 4) {
				log = Blocks.field_150364_r;
			} else {
				log = Blocks.field_150363_s;
				logMeta -= 4;
			}
			ItemStack randomLog = new ItemStack(log, logsAmount, logMeta);

			recipeList.add(new MerchantRecipe(randomLog, new ItemStack(Items.field_151166_bC, emeraldsAmount), itemToSell));
		}
	}

	public static class GiveItemForTwoItems implements EntityVillager.ITradeList {

		public final ItemStack buyingItemStack;
		@Nullable
		public final EntityVillager.PriceInfo buyingPriceInfo;

		public final ItemStack buyingItemStackTwo;
		@Nullable
		public final EntityVillager.PriceInfo buyingPriceItemTwoInfo;

		public final ItemStack sellingItemstack;
		@Nullable
		public final EntityVillager.PriceInfo sellingPriceInfo;

		public GiveItemForTwoItems(
				ItemStack buyingItemStack,
				@Nullable EntityVillager.PriceInfo buyingPriceInfo,
				ItemStack buyingItemStackTwo,
				@Nullable EntityVillager.PriceInfo buyingPriceItemTwoInfo,
				ItemStack sellingItemstack,
				@Nullable EntityVillager.PriceInfo sellingPriceInfo) {
			this.buyingItemStack = buyingItemStack;
			this.buyingPriceInfo = buyingPriceInfo;
			this.buyingItemStackTwo = buyingItemStackTwo;
			this.buyingPriceItemTwoInfo = buyingPriceItemTwoInfo;
			this.sellingItemstack = sellingItemstack;
			this.sellingPriceInfo = sellingPriceInfo;
		}

		@Override
		public void func_190888_a(IMerchant merchant, MerchantRecipeList recipeList, Random random) {
			int buyAmount = 1;
			if (this.buyingPriceInfo != null) {
				buyAmount = this.buyingPriceInfo.func_179412_a(random);
			}

			int buyTwoAmount = 1;
			if (this.buyingPriceItemTwoInfo != null) {
				buyTwoAmount = this.buyingPriceItemTwoInfo.func_179412_a(random);
			}

			int sellAmount = 1;
			if (this.sellingPriceInfo != null) {
				sellAmount = this.sellingPriceInfo.func_179412_a(random);
			}

			ItemStack buyItemStack = this.buyingItemStack.func_77946_l();
			buyItemStack.func_190920_e(buyAmount);
			ItemStack buyItemStackTwo = this.buyingItemStackTwo.func_77946_l();
			buyItemStackTwo.func_190920_e(buyTwoAmount);
			ItemStack sellItemStack = this.sellingItemstack.func_77946_l();
			sellItemStack.func_190920_e(sellAmount);
			recipeList.add(new MerchantRecipe(buyItemStack, buyItemStackTwo, sellItemStack));
		}
	}
}
